.. include:: ../BADGES.rst

.. _tappy_documentation:

tappy
=====

This is the home page for tappy.  tappy is a command line program and
Python library to perform tidal constituent analysis on a water elevation data
set.

tappy should work with Python 3.7.1+.

Table of Contents
-----------------
.. toctree::
   :maxdepth: 2

   readme
   TappyUsersGuide
   FillMissing
   CompareTidalFilters
   HarmonicAnalysis
   TidalScience
   command_line
   function_summary
   contributing
   authors
   license

Other Projects
--------------
http://timcera.bitbucket.io
